
# Slot: started at time




URI: [core:started_at_time](https://w3id.org/linkml/tests/core/started_at_time)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Date](types/Date.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | prov:startedAtTime |

